==> himmelsstuermer-0.1.3-20241113.232958-173.jar: himmelsstuermer/java/ClojureLambdaHandler.java <==
package himmelsstuermer.java;

// Import necessary Clojure and Java classes
import clojure.java.api.Clojure;
import clojure.lang.IFn;
import com.amazonaws.services.lambda.runtime.Context;
import java.util.List;
import java.util.Map;

public class ClojureLambdaHandler {
    static {
        try {
            System.out.println("Initializing Clojure environment...");

            // Get the 'require' function from 'clojure.core'
            IFn require = Clojure.var("clojure.core", "require");
            System.out.println("Require function obtained: " + require);

            // Read the namespace symbol
            Object namespaceSymbol = Clojure.read("himmelsstuermer.core");
            System.out.println("Namespace symbol obtained: " + namespaceSymbol);

            // Invoke 'require' on the namespace
            require.invoke(namespaceSymbol);
            System.out.println("Namespace required successfully");
        } catch (Exception e) {
            System.out.println("Exception during static initialization: " + e);
            e.printStackTrace();
        }
    }

    // Handle SQS event payloads and include context
    public static void handleRequest(Map<String, Object> event, Context context) {
        System.out.println("Lambda invoked with context: " + context.getAwsRequestId());

        // Extract the "Records" array from the event
        List<Map<String, Object>> records = (List<Map<String, Object>>) event.get("Records");

        // Check if records are present
        if (records != null) {
            // Pass the message and context information to your Clojure function for further processing
            IFn myFunction = Clojure.var("himmelsstuermer.core", "-main");  // Replace with your function name
            myFunction.invoke(records, context);  // Invoke the Clojure function with the message body and context
        } else {
            System.out.println("No records to process.");
        }
    }
}

==> himmelsstuermer-0.1.4-20241115.110751-6.jar: himmelsstuermer/java/ClojureLambdaHandler.java <==
package himmelsstuermer.java;

// Import necessary Clojure and Java classes
import clojure.java.api.Clojure;
import clojure.lang.IFn;
import com.amazonaws.services.lambda.runtime.Context;
import java.util.List;
import java.util.Map;

public class ClojureLambdaHandler {
    static {
        try {
            System.out.println("Initializing Clojure environment...");

            // Get the 'require' function from 'clojure.core'
            IFn require = Clojure.var("clojure.core", "require");
            System.out.println("Require function obtained: " + require);

            Object coreNamespaceSymbol = Clojure.read("himmelsstuermer.core");
            System.out.println("Core namespace symbol obtained: " + coreNamespaceSymbol);

            require.invoke(coreNamespaceSymbol);
            System.out.println("Core namespace required successfully");
            
            Object storageNamespaceSymbol = Clojure.read("himmelsstuermer.core.storage");
            System.out.println("Storage namespace symbol obtained: " + coreNamespaceSymbol);

            require.invoke(storageNamespaceSymbol);
            System.out.println("Storage namespace required successfully");

            IFn setStorage = Clojure.var("himmelsstuermer.core.storage", "set-storage");
            setStorage.invoke();
            System.out.println("Storage setup function invoked successfully");
        } catch (Exception e) {
            System.out.println("Exception during static initialization: " + e);
            e.printStackTrace();
        }
    }

    // Handle SQS event payloads and include context
    public static void handleRequest(Map<String, Object> event, Context context) {
        System.out.println("Lambda invoked with context: " + context.getAwsRequestId());

        // Extract the "Records" array from the event
        List<Map<String, Object>> records = (List<Map<String, Object>>) event.get("Records");

        // Check if records are present
        if (records != null) {
            // Pass the message and context information to your Clojure function for further processing
            IFn myFunction = Clojure.var("himmelsstuermer.core", "-main");  // Replace with your function name
            myFunction.invoke(records, context);  // Invoke the Clojure function with the message body and context
        } else {
            System.out.println("No records to process.");
        }
    }
}
